Instrument

Struct Instrument 

pub struct Instrument<P: Read + Write> { /* private fields */ }
A general instrument interface that can be built with any interface that implements std::io::Read and std::io::Write.

This struct can be used to communicate with instruments over the various interfaces. Handy shortcuts for creating various interfaces are provides as well. However, this general implementation can also be used with any other types that are not provided by InstrumentRs.

Example

The following shows a simple example on how to create an Instrument interface from your own interface that implements std::io::Read and std::io::Write. Of course, to just use a simple std::net::TcpStream as shown here, you can also use the crate::TcpIpInterface interface.

use std::{net::TcpStream, time::Duration};

use instrumentrs::Instrument;

let my_interface = TcpStream::connect("192.168.10.1:8000").unwrap();
let inst_interface = Instrument::new(my_interface, Duration::from_secs(3));

Implementations

Source

impl<P: Read + Write> Instrument<P>

pub fn new(port: P, timeout: Duration) -> Self

Try to create a new instance of Instrument with a given interface.